==============
API References
==============

Ribbon Bar
----------

RibbonBar
~~~~~~~~~

.. autoclass:: pyqtribbon.ribbonbar.RibbonBar
   :members:
   :show-inheritance:

Ribbon Title
------------

RibbonApplicationButton
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.titlewidget.RibbonApplicationButton
   :members:
   :show-inheritance:

RibbonTabBar
~~~~~~~~~~~~

.. autoclass:: pyqtribbon.tabbar.RibbonTabBar
   :members:
   :show-inheritance:

RibbonTitleLabel
~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.titlewidget.RibbonTitleLabel
   :members:
   :show-inheritance:

RibbonTitleWidget
~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.titlewidget.RibbonTitleWidget
   :members:
   :show-inheritance:

Ribbon Stacked Widget

RibbonStackedWidget
~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.ribbonbar.RibbonStackedWidget
   :members:
   :show-inheritance:

Ribbon Category
---------------

RibbonCategory
~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.category.RibbonCategory
   :members:
   :show-inheritance:

RibbonNormalCategory
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.category.RibbonNormalCategory
   :members:
   :show-inheritance:

RibbonContextCategory
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.category.RibbonContextCategory
   :members:
   :show-inheritance:

RibbonContextCategories
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.category.RibbonContextCategories
   :members:
   :show-inheritance:

RibbonCategoryStyle
~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.category.RibbonCategoryStyle
   :members:
   :show-inheritance:

RibbonCategoryScrollArea
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.categorylayoutwidget.RibbonCategoryScrollArea
   :members:
   :show-inheritance:

RibbonCategoryScrollAreaContents
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.categorylayoutwidget.RibbonCategoryScrollAreaContents
   :members:
   :show-inheritance:

RibbonCategoryLayoutButton 
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.categorylayoutwidget.RibbonCategoryLayoutButton
   :members:
   :show-inheritance:

RibbonCategoryLayoutWidget
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.categorylayoutwidget.RibbonCategoryLayoutWidget
   :members:
   :show-inheritance:

Ribbon Panel
------------

RibbonPanel
~~~~~~~~~~~

.. autoclass:: pyqtribbon.panel.RibbonPanel
   :members:
   :show-inheritance:

RibbonPanelItemWidget
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.panel.RibbonPanelItemWidget
   :members:
   :show-inheritance:

RibbonSpaceFindMode
~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.panel.RibbonSpaceFindMode
   :members:
   :show-inheritance:

RibbonGridLayoutManager
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.panel.RibbonGridLayoutManager
   :members:
   :show-inheritance:

Ribbon Gallery
--------------

RibbonGallery
~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.gallery.RibbonGallery
   :members:
   :show-inheritance:

RibbonGalleryListWidget
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.gallery.RibbonGalleryListWidget
   :members:
   :show-inheritance:

RibbonGalleryButton
~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.gallery.RibbonGalleryButton
   :members:
   :show-inheritance:

RibbonGalleryPopupListWidget
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.gallery.RibbonGalleryPopupListWidget
   :members:
   :show-inheritance:

RibbonPopupWidget
~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.gallery.RibbonPopupWidget
   :members:
   :show-inheritance:

Ribbon Tool Button
------------------

RibbonToolButton
~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.toolbutton.RibbonToolButton
   :members:
   :show-inheritance:

RibbonButtonStyle
~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.toolbutton.RibbonButtonStyle
   :members:
   :show-inheritance:

Ribbon Separator
----------------

RibbonSeparator
~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.separator.RibbonSeparator
   :members:
   :show-inheritance:

RibbonHorizontalSeparator
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.separator.RibbonHorizontalSeparator
   :members:
   :show-inheritance:

RibbonVerticalSeparator
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.separator.RibbonVerticalSeparator
   :members:
   :show-inheritance:

Ribbon Menu
-----------

RibbonMenu
~~~~~~~~~~

.. autoclass:: pyqtribbon.menu.RibbonMenu
   :members:
   :show-inheritance:

RibbonPermanentMenu
~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyqtribbon.menu.RibbonPermanentMenu
   :members:
   :show-inheritance: